##  Step 2. Evaluate Data
This step aims to establish a target architecture (to-be), identify gaps between the current and future states, and enrich your Transformation Program with information that empowers the entire team to monitor progress and understand the changes in the IT landscape.
There are several ways to visualize the future state of your architecture/ Impacts of Transformations on your architecture through enhanced Report capabilities. To learn more about the reporting capabilities enabled by the SAP LeanIX Architecture and Road Map Planning, refer to [Reports and Roadmaps](https://help.sap.com/docs/leanix/ea/reports-and-roadmaps?locale=en-US&state=PRODUCTION&version=CLOUD "Reports offer valuable insights throughout—from gaining clarity and visualizing target architecture to comparing scenarios, planning roadmaps, and monitoring progress."). A few examples are shown below:
  * In this example, you can see an Application Landscape Report that reflects the Impacts of your Transformations on your application landscape:
![Application Landscape Report reflecting the Impacts of your Transformations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c93847a4410148bd5ce496768496e_LowRes.png)
Application Landscape Report reflecting the Impacts of your Transformations
  * Application Landscape Reports showing how different scenarios are going to affect the IT architecture:
Example for Option A:
![Option A: Application Landscape Reports showing the effect on IT landscape](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a7fd17a44101493afc7f8c6ee537b_LowRes.png)
Option A: Application Landscape Reports showing the effect on IT landscape
Example for Option B:
![Option A: Application Landscape Reports showing the effect on IT landscape](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ea0e37a441014aec7b9576e8ce085_LowRes.png)
Option B: Application Landscape Reports showing the effect on the IT landscape
  * You can also use the Roadmap Report to see how certain aspects of your landscape change over time due to the selection of one or more Initiatives:
![Project Roadmap Report showing impacts of SAP S/4 HANA implementation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751f9957a441014b473e7d3da61f960_LowRes.png)
Project Roadmap Report showing impacts of SAP S/4 HANA implementation
  * Interface Circle Map showing how the SAP S/4HANA migration will affect the integration architecture:
![Interface Circle Map showing how the SAP S/4HANA migration will affect the integration architecture](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274469717a441014ab0cec88ad11d130_LowRes.png)
Interface Circle Map showing how the SAP S/4HANA migration will affect the integration architecture
  * The example below displays Impacts in the Application Landscape Report helping you identify deviations from the standard and pinpoint areas where technical debt has been accumulated:
![Application Landscape Report showing accumulated technical debt](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747bbcb7a441014b44e924fdc834ba4_LowRes.png)
Application Landscape Report showing accumulated technical debt
